{ pkgs, config, ... }:
let
  nvimCustom = import ./nvim/settings.nix;
in
{
  imports = [
    ./fish/settings.nix
    ./variables.nix
    ./i3/settings.nix
    ./sway/settings.nix
    ./kitty/settings.nix
    ./rofi/settings.nix
    ./i3/i3status-rust.nix
    ./dunst/settings.nix
    ./helix/settings.nix
    # ./polybar/config.nix
    # ./hyprland/settings.nix
    # ./waybar/settings.nix
  ];

  home-manager.users.zoe = {
    home.stateVersion = "22.11";
    programs.neovim = nvimCustom pkgs;

    programs.git = {
      enable = true;
      userName = "zoe";
      userEmail = "ZoeOosting@outlook.com";
    };

    xdg.configFile."avizo/config.ini".source = ./avizo.ini;

    programs.mpv.config = {
      enable = true;
      ytdl-format = "bestvideo[height<=?720]+bestaudio/best";
      save-position-on-quit = true;
    };
    programs.yt-dlp = {
      enable = true;
      settings = {
        format = "bestaudio*[height<=720][fps<=24]";
      };
    };

    services.picom = {
      enable = true;
      package = pkgs.picom;
      fade = true;
      fadeDelta = 2;
      extraArgs = [ "--experimental-backends" ];
      settings = { };
    };

    programs.ssh.enable = true;
    programs.ssh.matchBlocks = {
      "cookie" = {
        user = "bat";
        forwardX11Trusted = true;
        forwardX11 = true;
      };
      "wr-cluster" = {
        user = "oosting";
        forwardX11Trusted = true;
        forwardX11 = true;
      };
    };
    home.pointerCursor = {
      x11.enable = true;
      package = pkgs.catppuccin-cursors.frappePink;
      name = "Catppuccin-Frappe-Pink-Cursors";
      size = 42;
    };

    gtk = {
      enable = true;
      font = {
        name = config.font.regular;
        package = null;
        size = 11;
      };
      iconTheme = {
        name = "Papirus-Dark";
        package = pkgs.papirus-icon-theme;
      };
      theme = {
        name = "Catppuccin-Green-Dark";
        package = pkgs.catppuccin-gtk;
      };
    };
    programs.starship =
      let
        flavour = "frappe"; # One of `latte`, `frappe`, `macchiato`, or `mocha`
      in
      {
        enable = true;
        enableFishIntegration = true;
        settings = {
          # Other config here
          format = "$all"; # Remove this line to disable the default prompt format
          palette = "catppuccin_${flavour}";
        } // builtins.fromTOML (builtins.readFile
          (pkgs.fetchFromGitHub
            {
              owner = "catppuccin";
              repo = "starship";
              rev = "3e3e54410c3189053f4da7a7043261361a1ed1bc";
              sha256 = "soEBVlq3ULeiZFAdQYMRFuswIIhI9bclIU8WXjxd7oY=";
            } + /palettes/${flavour}.toml));
      };
    programs.bat = {
      enable = true;
      config.theme = "catppuccinFrappe";
      themes = {
        catppuccinFrappe = builtins.readFile (pkgs.fetchFromGitHub
          {
            owner = "catppuccin";
            repo = "bat";
            rev = "ba4d16880d63e656acced2b7d4e034e4a93f74b1";
            sha256 = "6WVKQErGdaqb++oaXnY3i6/GuH2FhTgK0v4TN4Y0Wbw=";
          } + "/Catppuccin-frappe.tmTheme");
      };
    };
  };
}
