{ pkgs, supercolor, nixpkgs-unstable, kaokao, i3layouts-rofi, ... }:
let
  my-python-packages = p: with p; [ pytest i3ipc python-lsp-server ];
  rust = pkgs.latest.rustChannels.stable.rust.override {
    extensions = [ "rust-src" ];
  };
in {
  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.zoe = {
    shell = pkgs.fish;
    isNormalUser = true;
    description = "zoe";
    extraGroups = [
      "networkmanager"
      "wheel"
      "libvirtd"
      "dialout"
      "adbusers"
      "user-with-access-to-virtualbox"
    ];
    packages = with pkgs; [
      # internet
      firefox
      firefox-devedition
      ungoogled-chromium
      qutebrowser
      curl
      git
      networkmanagerapplet
      thunderbird
      tor-browser-bundle-bin
      onionshare-gui
      mullvad-vpn
      syncthing
      qbittorrent
      telegram-desktop
      discord

      # files and partitions
      gnome.gnome-disk-utility
      gnome.nautilus
      xfce.thunar
      p7zip
      unzip
      tree
      writedisk
      postgresql

      # music / sound
      cmus
      pavucontrol
      playerctl
      pamixer
      projectm
      picard
      audacity
      qjackctl

      # video
      syncplay
      mpv
      yt-dlp
      youtube-dl
      obs-studio
      ffmpeg_6-full
      kdenlive
      vulkan-tools

      # images
      swaybg
      gnome.eog
      gimp
      krita
      gnome.cheese
      flameshot
      aseprite-unfree

      # pdf
      evince
      xournalpp

      # games
      steam
      pcsx2
      dolphin-emu
      sc-controller
      minetest
      airshipper
      lutris

      # x11
      xdotool
      arandr
      lxappearance
      wacomtablet
      i3layouts-rofi.packages.${pkgs.system}.default

      # terminal
      kitty
      supercolor.packages.${pkgs.system}.default
      kaokao.packages.${pkgs.system}.default
      thefuck
      lsd
      bat
      fd
      fzf
      tmux

      # window manager
      grim
      slurp
      swappy
      autotiling
      wdisplays
      xdg-desktop-portal-wlr
      xdg-desktop-portal

      # uni
      dbeaver
      zoom-us
      haskellPackages.Monadoro
      typst
      typst-lsp
      libreoffice

      # spelling
      hunspell
      hunspellDicts.en_US
      hunspellDicts.de_DE

      #3d print
      prusa-slicer

      #font
      fontforge-gtk

      # dev
      postman
      tokei
      vscode
      mdbook

      ## games
      unstable.godot_4

      ## nix
      any-nix-shell
      nixfmt
      nil
      ## js
      nodejs
      nodePackages.prettier
      nodePackages.typescript-language-server
      nodePackages.live-server
      nodePackages_latest.vscode-langservers-extracted
      nodePackages_latest.svelte-language-server
      nodePackages_latest.svelte-check
      ## rust
      rust
      cargo-watch
      llvmPackages_rocm.clang
      llvmPackages_rocm.llvm
      mold
      libclang
      taplo
      cargo-outdated
      cargo-generate
      ## go
      air
      go
      gopls
      delve

      ## swagger
      openapi-generator-cli

      ## python
      (python311.withPackages my-python-packages)
      python39
      black
      ## dotlang
      graphviz
      ## 3d
      blender
      blockbench-electron
      ## arduino
      arduino
      ## tilemap editor
      ldtk
      ## android
      android-tools

      # help
      tealdeer

      # nix tools
      ## formatter for .nix files
      nixpkgs-fmt
      ## find nix packages containing certain files
      nix-index

      # system tools
      mesa-demos
      wl-clipboard
      jq
      eva
      xf86_input_wacom
      xorg.xkill
      neofetch
      htop
      bat
      du-dust
      gnome.gnome-clocks
      blueberry
      killall
      appimage-run
      xclip
      zip
      bottom
      tmux
      zellij
      sshfs
      unp
    ];
  };

}
