{ config, pkgs, hyprland, ... }:
{
  home-manager.users.zoe.programs.waybar = {
    enable = true;
    package = hyprland.packages.${pkgs.system}.waybar-hyprland;
    settings = {
      mainBar = {
        layer = "top";
        position = "top";
        height = 30;
        modules-left = [ "wlr/workspaces" "wlr/taskbar" "hyprland/submap" ];
        modules-center = [ "mpris" ];
        modules-right = [ "network" "upower" "clock" "tray" ];
        
        "wlr/taskbar" = {
          "format" = "{icon}";
          "on-click" = "activate";
          "on-click-middle" = "close";
        };

        "hyprland/submap" = {
          "format" = "{}";
        };
        
        "clock" = {
          "format" = "{:%H:%M}";
        };
        
        "network" = {
          format = "{essid}{signalStrength}";
          format-disconnected = "NO NETWORK";
          tooltip = "false";
        };
        
        "upower" = {
          "hide-if-empty" = "true";
        };

        "mpris" = {
          "format" = "{status_icon} {artist} - {title}";
          "status-icons" = {
            "paused" = "paused!";
            "playing" = "jamming!";
          };
        };
      };
    };
    style = ''
    * {
      font-family: "CaskaydiaCove Nerd Font";
      font-size: 14px;
      background: none;
      color: #${config.color.foreground};
      min-height: 24px;
      padding: 0px 4px;
      margin: 0;
    }

    window#waybar,
    tooltip {
      border-bottom: 2px solid #${config.color.green};
      background: alpha(#${config.color.background}, 0.9);
    }

    #workspaces button:hover {
      box-shadow: inherit;
      text-shadow: inherit;
    }
    
    #workspaces button.active label{
      color: #${config.color.green};
    }
    
    #submap {
      color: #${config.color.red};
    }
    '';
  };
}
